<?php
/**
 * Plugin Configurateur de squelettes
 * Copyright (c) Christophe IMBERTI
 * Licence Creative commons by-nc-sa
 */

include_spip('inc/ciparam_inc_meta');


/*-----------------------------------------------------------------
// Balises supplementaires
// SPIP permet de les placer dans le fichier ..._fonctions.php
------------------------------------------------------------------*/

function balise_CIPARAM_MOTCLE_ACCUEIL_dist($p) {
	$p->code = "ciparam_lire_meta('ci_motcle_accueil')";
	// $p->statut = 'html';
	return $p;
}

function balise_CIPARAM_NOM_BANDEAU_dist($p) {
	$p->code = "ciparam_lire_meta('ci_nom_bandeau')";
	// $p->statut = 'html';
	return $p;
}

function balise_CIPARAM_ABONNEMENT_XITI_dist($p) {
	$p->code = "ciparam_abonnement_xiti()";
	// $p->statut = 'html';
	return $p;
}

function balise_CIPARAM_PIWIK_URL_dist($p) {
	$p->code = "ciparam_piwik_url()";
	// $p->statut = 'html';
	return $p;
}

function balise_CIPARAM_PIWIK_ID_dist($p) {
	$p->code = "ciparam_piwik_id()";
	// $p->statut = 'html';
	return $p;
}

function balise_CIPARAM_MAINTENANT_dist($p) {
	$p->code = 'date("Y-m-d")';
	// $p->statut = 'php';
	return $p;
}

function balise_CIPARAM_AFFICHER_dist($p) {
	$arg = interprete_argument_balise(1,$p);
	if (!$arg) {
		$p->code = "'oui'";
	} else 
	  $p->code = 'ciparam_afficher(' . $arg .')';
	  
	// $p->statut = 'html';
	return $p;
}

function balise_CIPARAM_IMAGE_BANDEAU_dist($p) {
	$p->code = "ciparam_image_bandeau()";
	// $p->statut = 'html';
	return $p;
}

function balise_CIPARAM_XITI_EMAIL_dist($p) {
	$p->code = "ciparam_xtor_email()";
	// $p->statut = 'html';
	return $p;
}

function balise_CIPARAM_XITI_RSS_dist($p) {
	$p->code = "ciparam_xtor_rss()";
	// $p->statut = 'html';
	return $p;
}

function balise_CIPARAM_XITI_ACTIF_dist($p) {
	$p->code = "ciparam_xiti_actif()";
	// $p->statut = 'html';
	return $p;
}

function balise_CIPARAM_PIWIK_ACTIF_dist($p) {
	$p->code = "ciparam_piwik_actif()";
	// $p->statut = 'html';
	return $p;
}

// Liste des marqueurs de statistique actifs
// Exemples : 'xiti', 'piwik', 'xiti,piwik', 'piwik,xiti'
function balise_CIPARAM_LISTE_MARQUEURS_dist($p) {
	$p->code = "ciparam_liste_marqueurs()";
	// $p->statut = 'html';
	return $p;
}

// Prefixe du squelette marqueur de statistique à utiliser
// Exemples : 'xiti', 'piwik', 'xitipiwik', 'compteur', ...
// Si aucun outil de statistique n'est actif, retourne ''
function balise_CIPARAM_PREFIXE_SQUELETTE_MARQUEUR_dist($p) {
	$p->code = "ciparam_prefixe_squelette_marqueur()";
	// $p->statut = 'html';
	return $p;
}

/*-----------------------------------------------------------------
// Criteres propres de ciparam
------------------------------------------------------------------*/

function critere_ciparam_nombreactu($idb, &$boucles, $crit) {
	$boucle = &$boucles[$idb];
	// respecter la syntaxe des cotes et double cotes
 	$boucle->limit = '"0," . intval(ciparam_lire_meta("ci_nbactu"))';	  
}

/*-----------------------------------------------------------------
// Filtres propres de ciparam
------------------------------------------------------------------*/

// Ne pas mettre des accents dans un mailto, etc.
function ciparam_filtre_mailto($texte,$charset='utf-8'){
        if (empty($texte)){
            return '';
        }

	$texte = str_replace(array("&#8217;","&#8220;","&#8221;"),array(" ","",""),$texte);
	$texte = str_replace(array("&mdash;", "&endash;"),array("--","-"),$texte);

	$texte = htmlentities($texte, ENT_NOQUOTES, $charset);
	$texte = preg_replace('#\&([A-za-z])(?:acute|cedil|circ|grave|ring|tilde|uml)\;#', '\1', $texte);
	$texte = preg_replace('#\&([A-za-z]{2})(?:lig)\;#', '\1', $texte);
	$texte = preg_replace('#\&[^;]+\;#', ' ', $texte);
	$texte = str_replace('nbsp;', ' ', $texte);
	$texte = str_replace("'", " ", $texte);
	$texte = str_replace('"', '', $texte);

	return $texte;
}

// Sommaire automatique d'un article
// Source : http://www.uzine.net/spip_contrib/article.php3?id_article=76
function ciparam_sommaire_article($texte) {
	
	preg_match_all("|<h3 class=\"spip\">(.*)</h3>|U", $texte, $regs);
	
	$texte='';
	$texte.='<form name="accestitre" action="Javascript:goToSelectURL(\'accestitre\',\'nom_titre\');" method="get" >';
	$texte.='<select name="nom_titre" id="nom_titre">';
	$texte.='<option value="" selected="selected">'._T('ciparam:acces_direct').'</option>';
	
	$nb=1;
	
	for($j=0;$j<count($regs[1]);$j++){
            if (!empty($regs[1][$j])){
	        $item = $regs[1][$j];
	        // met des espaces insecables
	        $item = str_replace(" ","&nbsp;",$item);
	    	$texte=$texte.'<option value="#sommaire_'.$nb.'">'.$item.'</option>';
			$nb++;
            }
	}
	$texte.='</select>';
	$texte.='<input type="submit" name="masquable" value="OK"></input>';
	$texte.='</form>';

	    
    // Ajout CI pour eviter la duplication des notes de bas de page
	$GLOBALS["les_notes"] = "";
	$GLOBALS["compt_note"] = 0;
	$GLOBALS["marqueur_notes"] = 0;

    return $texte;
}

function ciparam_sommaire_article2($texte){
	preg_match_all("|<h3 class=\"spip\">(.*)</h3>|U", $texte, $regs);
	
	$texte='';
	$texte.='<form name="accestitre2" action="Javascript:goToSelectURL(\'accestitre2\',\'nom_titre2\');" method="get" >';
	$texte.='<select name="nom_titre2" id="nom_titre2">';
	$texte.='<option value="" selected="selected">'._T('ciparam:acces_direct').'</option>';
	
	$nb=1;
	
	for($j=0;$j<count($regs[1]);$j++)	{
            if (!empty($regs[1][$j])){
	        $item = $regs[1][$j];
	        // met des espaces ins�cables
	        $item = str_replace(" ","&nbsp;",$item);
	    	$texte=$texte.'<option value="#sommaire_'.$nb.'">'.$item.'</option>';
			$nb++;
            }
	}
	$texte.='</select>';
	$texte.='<input type="submit" value="OK"></input>';
	$texte.='</form>';

	    
    // Ajout CI pour eviter la duplication des notes de bas de page
	$GLOBALS["les_notes"] = "";
	$GLOBALS["compt_note"] = 0;
	$GLOBALS["marqueur_notes"] = 0;

    return $texte;
}

function ciparam_sommaire_ancre($texte){
        if (empty($texte)){
            return '';
        }
	$texte = preg_replace("|<h3 class=\"spip\">(.*)</h3>|U","<a name=\"sommaire_#NB_TITRE_DE_MON_ARTICLE#\" href=\"#top\"></a>$0", $texte);
	$texte = str_replace("<h3 class=\"spip\">","",$texte);
	$texte = str_replace("<a name=\"sommaire_","<h3 class=\"spip\"><a name=\"sommaire_",$texte);
	$array = explode("#NB_TITRE_DE_MON_ARTICLE#" , $texte);
	$res =count($array);
	$i =1;
	$texte=$array[0];
	while($i<$res)
	{
		$texte=$texte.$i.$array[$i];
		$i++;
	}
	
	return $texte;
}

function ciparam_texte_sans_http($texte) {
    if (!empty($texte)){
        if (substr($texte,0,7)=="http://"){
            $texte = substr($texte,7);
        } elseif (substr($texte,0,8)=="https://"){
            $texte = substr($texte,8);
        }
    }
    return $texte;
}

function ciparam_texte_sans_nbsp($texte) {
    if (!empty($texte)){
        // supprimer les &nbsp;
        $texte=str_replace("&nbsp;?","?",$texte);
    }
    return $texte;
}

function ciparam_texte_export($texte,$charset='') {
    if (!empty($texte)){
        // supprimer les &nbsp;
        $texte=str_replace("&nbsp;"," ",$texte);

        // supprimer les retour a la ligne d'un texte
        $texte=str_replace(CHR(13),"",$texte);
        $texte=str_replace(CHR(10),"",$texte);

        // mettre des URL entieres
    //    $monurl = $GLOBALS['meta']['adresse_site'];
    //    $texte = str_replace("IMG/", $monurl."/IMG/", $texte);

        // charset site cible different
        if ($charset) {
            if ($charset!=$GLOBALS['meta']['charset']) {
                    if (in_array($charset,array('iso-8859-1','utf-8','utf8'))) {
                                    include_spip('inc/charsets');
                                    $texte = unicode2charset(charset2unicode($texte), $charset);
                    }
            }
        }
    }
    return $texte;
}

function ciparam_xtTraiter($nompage) {
    if (!empty($nompage)){
	if (time() < strtotime("1 January 2013")) {

		// ancien code issu de www.spip-contrib.net/Mesurez-l-audience-de-votre-site
		$nompage = strtolower($nompage);
		$nompage = preg_replace("[���]","a",$nompage);
		$nompage = preg_replace("[��]","i",$nompage);
		$nompage = preg_replace("[��]","o",$nompage);
		$nompage = preg_replace("[���]","u",$nompage);
		$nompage = preg_replace("[����]","e",$nompage);
		$nompage = str_replace("�","a",$nompage);
		$nompage = str_replace("�","i",$nompage);
		$nompage = str_replace("�","o",$nompage);
		$nompage = str_replace("�","u",$nompage);
		$nompage = str_replace("�","e",$nompage);
		$nompage = str_replace("�","c",$nompage);
		$nompage = preg_replace("[^a-z^A-Z^0-9^\-_:~\\\/]","_",$nompage);

	} else {

		$safe = '';
		// passer en minuscule
		$t = strtolower(trim($nompage));
		include_spip('inc/filtres');	
		$t = filtrer_entites($t);
	
		if ($t) {
			// supprimer les accents
			include_spip('inc/charsets');
			$tsa = translitteration($t);
		
			// Les caracteres autorises par XITI sont les suivants :
			// - les lettres abcdefghijklmnopqrstuvwxyz en majuscules ou minuscules
	    	// - les chiffres 123467890
			// - les points, les slashs, les moins, les underscores, les tildes
			// ajout des deux points pour compatibilite ascendante
			$tableau = array('.','/','-','_','~',':');
			$tscs = str_replace($tableau,'',$tsa);		
			if (!ctype_alnum($tscs)) {
				// enlever les caracteres speciaux (sauf ceux qui sont autorises)
				$longueur = strlen($tsa);
			    for ($i = 0; $i < $longueur; $i++){
			    	if (ctype_alnum($tsa[$i]) OR in_array($tsa[$i], $tableau))
			    		$safe .= $tsa[$i];
			    	else
			        	$safe .= ' ';
			    }
			} else {
				$safe = $tsa;
			}
			
		    // remplacer les espaces par des underscores
		    $nompage = str_replace(' ','_',$safe);		
		}
	}
    } 
    return($nompage);
}

// Pour les flux RSS
function ciparam_mime_type($type_document) {

	$retour="";
	if ($type_document) {
		$result = sql_select("*", "spip_types_documents", "titre='$type_document'","","");		
		if ($type = sql_fetch($result))	{
			$retour = $type['mime_type'];
		}
	}
	    
	return $retour;
}

function ciparam_antislash($texte) {
    if (!empty($texte)){
        // met des antislash
	$texte=str_replace('/', '\/',$texte);
    }
    return $texte;
}

function ciparam_utf8($texte) {
    if (!empty($texte)){
        // conversion en utf8
	$texte = ciparam_iso_to_utf8($texte); 
    }
    return $texte;
}

// From http://svn.ilias.uni-koeln.de/wsvn/ILIAS3/trunk/include/inc.convertcharset.php
function ciparam_iso_to_utf8($str) {
//    if (extension_loaded("mbstring"))
//        return mb_convert_encoding($str, "UTF-8", "auto");;
    if (empty($str)){
        return '';
    }
    
    for($x=0;$x<strlen($str);$x++) {
        $num=ord(substr($str,$x,1));
      if($num<128)
          $xstr.=chr($num); 
      elseif($num<1024)
          $xstr.=chr(($num>>6)+192).chr(($num&63)+128);
      elseif($num<32768)
          $xstr.=chr(($num>>12)+240).chr((($num>>6)&63)+128).chr(($num&63)+128);
      elseif($num<2097152)
          $xstr.=chr($num>>18+240).chr((($num>>12)&63)+128).chr(($num>>6)&63+128).chr($num&63+128);
    }
    return $xstr;
}

function ciparam_remet_balise($texte) {
    if (!empty($texte)){
	$texte=str_replace('&lt;', '<',$texte);	   
	$texte=str_replace('&gt;', '>',$texte);	   
    }
    return $texte;
}

function ciparam_select_annees($premiere_annee,$derniere_annee) {
	$return = "";

	$premiere_annee = intval($premiere_annee);
	$derniere_annee = intval($derniere_annee);

	if ($premiere_annee AND $derniere_annee AND $derniere_annee >= $premiere_annee) {
		$annee = $derniere_annee;	
		while($annee >= $premiere_annee) {
			$return .= '<option value="'.$annee.'-01-01">'.$annee.'</option>';
			$annee = $annee - 1;
		}
	}
	
	return $return;
}

function ciparam_volumetrie_site($site) {
	$return = '';
        $date_sql = '';
        $timestamp_sql = '';
        
	if (_request('datedebut')) {
            $date_sql = ciparam_verifier_et_convertir_date_en_sql(_request('datedebut'));
            $timestamp_sql = ciparam_verifier_et_convertir_date_en_timestamp_sql(_request('datedebut'));
	}
	
	// nombre d'auteurs du site (hors visiteurs)
        $where1 = "statut<>'5poubelle' AND statut<>'6forum'";
	$return = sql_countsel("spip_auteurs",$where1,"","");
	
	// nombre de rubriques du site
        $where2 = "";
        if ($timestamp_sql){
            // date de maj de la rubrique
            $where2 .= "maj>=".$timestamp_sql;
        }
	$return .= "_".sql_countsel("spip_rubriques",$where2,"","");
	
	// nombre d'articles du site
        $where3 = "statut<>'poubelle'";
        if ($date_sql){
            // date de publication de l'article
            $where3 .= " AND date>=".$date_sql;
        }
	$return .= "_".sql_countsel("spip_articles",$where3,"","");

	// nombre d'auteurs du site avec au moins un article
        if ($date_sql){
            // Eviter une double jointure qui dégraderait les performances 
            $where4 = "art.objet='article' AND lien.date>=".$date_sql;
            $return .= "_".sql_countsel("spip_auteurs_liens AS art LEFT JOIN spip_articles AS lien ON art.id_objet=lien.id_article",$where4,"art.id_auteur","");
        } else {
            $where4 = "objet='article' AND statut<>'5poubelle' AND statut<>'6forum'";
            $return .= "_".sql_countsel("spip_auteurs_liens AS art LEFT JOIN spip_auteurs AS lien ON art.id_auteur=lien.id_auteur",$where4,"art.id_auteur","");
        }
        
        

	// nombre de documents du site
	$where5 = "distant='non'";
	if (_request('extension')) {
		$extension = _request('extension');
		$tscs = str_replace('_','',$extension);
		if (ctype_alnum($tscs)) {
			$safe = array();
			$typesdoc = explode('_',$extension);
			if (count($typesdoc)<11) {
				foreach ($typesdoc as $typedoc) {
					if (ctype_alnum($typedoc) AND strlen($typedoc)<8)
						$safe[] = $typedoc;
				}
				if ($safe)
					$where5 = "distant='non' AND ".sql_in('extension', $safe);
			}
		}
	}        
        if ($date_sql){
            // date de televersement du document
            $where5 .= " AND date>=".$date_sql;
        }
	$return .= "_".sql_countsel("spip_documents",$where5,"","");

	// nombre de commentaires publies sur le site public
        $where6 = "statut='publie'";
        if ($date_sql){
            // attention : date_heure au lieu de date
            $where6 .= " AND date_heure>=".$date_sql;
        }
	$return .= "_".sql_countsel("spip_forum",$where6,"","");

	// nombre de commentaires dans l'expace prive
        $where7 = "statut='prive'";
        if ($date_sql){
            // attention : date_heure au lieu de date
            $where7 .= " AND date_heure>=".$date_sql;
        }
	$return .= "_".sql_countsel("spip_forum",$where7,"","");

	// nombre d'articles archive
        $where8 = "statut='archive'";
        if ($timestamp_sql){
            // date de maj de l'article
            $where8 .= " AND maj>=".$timestamp_sql;
        }
	$return .= "_".sql_countsel("spip_articles",$where8,"","");
	
	return $return;
}

function ciparam_verifier_et_convertir_date_en_sql($date='') {
	$return = false;

   	if ($date) {
	    list($d,$m,$y) = explode("/",$date);
	    if ($d!='' AND $m!='' AND $y!='') {
                if (is_numeric($y) AND is_numeric($m) AND is_numeric($d) AND intval($y)>=1000) {
                    if (checkdate($m,$d,$y)){
                        // format "Y-m-d H:i:s"
                        $return = sql_quote($y.'-'.$m.'-'.$d.' 00:00:00');
                    }
                }
	    } 
   	}

   	return $return;
}

function ciparam_verifier_et_convertir_date_en_timestamp_sql($date='') {
	$return = false;

   	if ($date) {
	    list($d,$m,$y) = explode("/",$date);
	    if ($d!='' AND $m!='' AND $y!='') {
                if (is_numeric($y) AND is_numeric($m) AND is_numeric($d) AND intval($y)>=1000) {
                    if (checkdate($m,$d,$y)){
                        // format "YmdHis"
                        $return = sql_quote($y.$m.$d.'000000');
                    }
                }
	    } 
   	}

   	return $return;
}


/*-----------------------------------------------------------------
// Filtre pour le plan du site
------------------------------------------------------------------*/

// Construit le plan du site (volumetrie rubrique)
// Renvoi le plan a partir d'un tableau des rubriques concernees
// Chaque ligne du tableau passe en parametre de la fonction doit comprendre
// #ARRAY{id_parent,#ID_PARENT,id_rubrique,#ID_RUBRIQUE,titre,#TITRE}
function ciparam_plan($citableau){
	global $citexteplan;
	global $ciarboplan;
	
	$ciarboplan = ciparam_arbo_rubriques($citableau);
	$citexteplan = '<ul class="plansite">';
	ciparam_enfantplan(0);
	$citexteplan .= '</ul>';
	
	return $citexteplan;  
}

// Renvoi un  tableau associant chaque rubrique parente a un tableau de ses rubriques filles
// Chaque ligne du tableau passe en parametre de la fonction doit comprendre
// #ARRAY{id_parent,#ID_PARENT,id_rubrique,#ID_RUBRIQUE,titre,#TITRE}
function ciparam_arbo_rubriques($citableau) {
	$ciarbo = array();
	$cienfants = array();
	$ciparent = 0;
	$row = array();
	
	foreach ($citableau as $row){
		
		if ($ciparent) {
			if ($ciparent!=$row['id_parent']+1) {
                                $ciarbo["p".strval($ciparent-1)] = $cienfants;

				$ciparent = $row['id_parent']+1;
				$cienfants = array();
			}
		} else {
			$ciparent = $row['id_parent']+1;
		}
		
		$cienfants[] = array($row['id_rubrique'],$row['titre']);
	}
	// Traiter le dernier lot 
	if ($ciparent) {
		$ciarbo["p".strval($ciparent-1)] = $cienfants;
		$ciparent = $row['id_parent']+1;
		$cienfants = array();
	}

	return $ciarbo;
}

function ciparam_enfantplan($leparent){
	global $id_parent;
	global $id_rubrique;
	static $i = 0;
	global $ciarboplan;
	global $citexteplan;
	$ci_plan_niveau = ciparam_plan_niveau();
        
        
	$i++;
	 	
 	if (isset($ciarboplan["p".strval($leparent)]) AND $citableau = $ciarboplan["p".strval($leparent)]) {
		if ($i > 1)
	 		$citexteplan .= '<ul>';
		
	 	foreach($citableau as $row) {
			$my_rubrique=$row[0];
			$titre=$row[1];
			$ciclass = "";
	
			switch ($i) {
			case 1:
				$ciclass = "plansecteur";
				break;
			case 2:
				$ciclass = "planrubniv1";
				break;
			default:
				$ciclass = "planrub";
				break;
			}
	
 			$citexteplan .= '<li>';
 			
			$titre = interdire_scripts(supprimer_numero(typo(extraire_multi($titre))));
			$url = ciparam_generer_url($my_rubrique,"rubrique");
			$citexteplan .= '<a href="'.$url.'" class="'.$ciclass.'">'.$titre.'</a>';
	 		
                        // nombre maximal de niveaux du plan du site
                        if ($i < $ci_plan_niveau)
        			ciparam_enfantplan($my_rubrique);
                        
 			$citexteplan .= '</li>';
		}

		if ($i > 1)
			$citexteplan .= '</ul>';
	
 	}	
	$i=$i-1;
	
	return true;
}

function ciparam_plan_niveau(){
	static $plan_niveau = 0;
        
        if (!$plan_niveau){
            $ciparam_config = @unserialize($GLOBALS['meta']['ciparam']);
            if (isset($ciparam_config['ci_plan_niveau']))
                $plan_niveau = $ciparam_config['ci_plan_niveau'];

            if (!$plan_niveau) 
               $plan_niveau = 99;

            // Parametrage par constante dans un fichier d'options
            if (defined("_CIPARAM_PLAN_NIVEAU") AND intval(_CIPARAM_PLAN_NIVEAU)>0 AND intval(_CIPARAM_PLAN_NIVEAU)<100)
                    $plan_niveau = _CIPARAM_PLAN_NIVEAU;
        }

        return $plan_niveau;
}

/*-----------------------------------------------------------------
// Fonctions pour etre compatible avec la navigation en previsualisation
------------------------------------------------------------------*/

function ciparam_generer_url($id,$objet) {
	if (ciparam_exist_cipr()=="oui")
		return vider_url(cipr_preview(generer_url_entite($id,$objet)));
	else
		return vider_url(generer_url_entite($id,$objet));
}

function ciparam_exist_cipr() {
	static $ciExistCipr;
	
	if (!$ciExistCipr) {
		if (function_exists('cipr_preview'))
			$ciExistCipr = "oui";
		else
			$ciExistCipr = "non";
	}

	return $ciExistCipr;
}

/*-----------------------------------------------------------------
// Fonctions relatives aux balises suppl�mentaires
------------------------------------------------------------------*/

function ciparam_afficher($arg) {
	$return = "oui";
	if ($arg) {
		$valeurs = ciparam_lire_meta("ci_masquer");
		if ($valeurs)
			if (in_array($arg,$valeurs))
				$return = "non";
	}
	return $return;
}

// Reservation pour le multisites
function ciparam_image_bandeau() {
    $return = '';
    
    if ($GLOBALS['spip_version_branche']>=4){
        $info_logo = quete_logo_objet(0, 'site', 'on');
        if (isset($info_logo['chemin'])){
            $return = $info_logo['chemin'];
        }

    } else {	
	$nom = "siteon0";
	$formats_logos =  array ('gif', 'jpg', 'png');
	foreach ($formats_logos as $format) {
		if (@file_exists($d = (_DIR_LOGOS . $nom . '.' . $format))) {
			$return = $d;
		}
	}
	
	if (function_exists('cims_image_bandeau')){
		$return = cims_image_bandeau();
        }
    }
    
    return $return;
}


/*-----------------------------------------------------------------
// Balise pour le doctype
------------------------------------------------------------------*/

function balise_CIPARAM_DOCTYPE_dist($p) {
	$p->code = "ciparam_doctype()";
	// $p->statut = 'html';
	return $p;
}

function ciparam_doctype() {
	$lang = $GLOBALS['spip_lang'];
	$lang_dir = lang_dir(changer_typo($lang));
	
	if (defined('_CIPARAM_DOCTYPE') AND _CIPARAM_DOCTYPE=='xhtml')
		$return = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">'
				.'<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="'.$lang.'" lang="'.$lang.'" dir="'.$lang_dir.'">';
	else
		$return = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">'
				.'<html lang="'.$lang.'" dir="'.$lang_dir.'">';

	return $return;
}


/*-----------------------------------------------------------------
// Fonctions pour Xiti et Piwik
------------------------------------------------------------------*/
function ciparam_xtor_rss($var=''){
	$return = '';

	// si abonnement xiti
	if ($ci_abonnement_xiti = ciparam_lire_meta('ci_abonnement_xiti')) {
		if (strpos($ci_abonnement_xiti,'_images/void.gif')===false){
			$xiti_rss = intval(ciparam_lire_meta('ci_xiti_rss'));
			
			if (defined('_CI_XITI_RSS') AND intval(_CI_XITI_RSS)>0)
				$xiti_rss = intval(_CI_XITI_RSS);
			
			if ($xiti_rss>0)
				$return = '#xtor=RSS-'.$xiti_rss;
		}
	}

	// si abonnement piwik
        if (!$ci_abonnement_xiti OR strpos($ci_abonnement_xiti,'_images/void.gif')!==false){
            if (ciparam_piwik_url() AND ciparam_piwik_id()>0){
                $return = '#pk_campaign=flux-RSS';
            }
        }
        
	return $return;
}

function ciparam_xtor_email($var=''){
	$return = '';

	// si abonnement xiti
	if ($ci_abonnement_xiti = ciparam_lire_meta('ci_abonnement_xiti')) {
		if (strpos($ci_abonnement_xiti,'_images/void.gif')===false){
			$xiti_email = intval(ciparam_lire_meta('ci_xiti_email'));
			
			if (defined('_CI_XITI_EMAIL') AND intval(_CI_XITI_EMAIL)>0)
				$xiti_email = intval(_CI_XITI_EMAIL);
			
			if ($xiti_email>0)
				$return = '&xtor=EPR-'.$xiti_email;
		}
	}

	// si abonnement piwik
        if (!$ci_abonnement_xiti OR strpos($ci_abonnement_xiti,'_images/void.gif')!==false){
            if (ciparam_piwik_url() AND ciparam_piwik_id()>0){
                $return = '&pk_campaign=notification-par-mail';
            }
        }
        
	return $return;
}

function ciparam_xtsd($var=''){
	$return = '';
	
	if ($ci_abonnement_xiti = ciparam_lire_meta('ci_abonnement_xiti')) {
		if (strpos($ci_abonnement_xiti,'_images/void.gif')===false){
			$pos = strpos($ci_abonnement_xiti,'.');
			if ($pos!==false)
				$return = substr($ci_abonnement_xiti,0,$pos);
		}
	}

	return $return;
}

function ciparam_xtsite($var=''){
	$return = '';
	
	if ($ci_abonnement_xiti = ciparam_lire_meta('ci_abonnement_xiti')) {
		if (strpos($ci_abonnement_xiti,'_images/void.gif')===false){
			$pos = strpos($ci_abonnement_xiti,'s=');
			if ($pos!==false){
				$return = substr($ci_abonnement_xiti,$pos+2);
				$pos2 = strpos($return,'&');
				if ($pos2!==false)
					$return = substr($return,0,$pos2);
				
			}
		}	
	}

	return $return;
}

function ciparam_xtn2($var=''){
	$return = '';
	
	if ($ci_abonnement_xiti = ciparam_lire_meta('ci_abonnement_xiti')) {
		if (strpos($ci_abonnement_xiti,'_images/void.gif')===false){
			$pos = strpos($ci_abonnement_xiti,'s2=');
			if ($pos!==false){
				$return = substr($ci_abonnement_xiti,$pos+3);
				$pos2 = strpos($return,'&');
				if ($pos2!==false)
					$return = substr($return,0,$pos2-1);
				
			}
		}
	}

	return $return;
}

function ciparam_xt1($var=''){
	$url = '';
	
	if ($ci_abonnement_xiti = ciparam_lire_meta('ci_abonnement_xiti')) {
		if (strpos($ci_abonnement_xiti,'_images/void.gif')===false){
			$url = strtolower(trim($GLOBALS['meta']['adresse_site']));
			$url = str_replace(array("http://","https://"),"",$url);

			$pos = strpos($url,'.');
			if ($pos!==false)
				$url = substr($url,$pos);
				
			$pos = strpos($url,'/');
			if ($pos!==false)
				$url = substr($url,0,$pos);
				
		}
	}

	return $url;
}

function ciparam_abonnement_xiti(){
    $ci_abonnement_xiti = ciparam_lire_meta('ci_abonnement_xiti');
    
    if (!$ci_abonnement_xiti OR strpos($ci_abonnement_xiti,'_images/void.gif')!==false){
        if (ciparam_piwik_url() AND ciparam_piwik_id()>0){
            $ci_abonnement_xiti = 'piwik';
        }
    }

    return $ci_abonnement_xiti;
}

function ciparam_xiti_actif(){
    $return = false;
    $ci_abonnement_xiti = ciparam_lire_meta('ci_abonnement_xiti');
    
    if ($ci_abonnement_xiti AND strpos($ci_abonnement_xiti,'_images/void.gif')===false){
        $return = true;
    }

    return $return;
}

function ciparam_piwik_actif(){
    $return = false;
    
    if (ciparam_piwik_url() AND ciparam_piwik_id()>0){
        $return = true;
    }

    return $return;
}

function ciparam_piwik_url(){
    if (defined('_CIPARAM_PIWIK_URL') AND _CIPARAM_PIWIK_URL)
        $ciparam_piwik_url = _CIPARAM_PIWIK_URL;
    else
        $ciparam_piwik_url = ciparam_lire_meta('ci_piwik_url');

    if ($ciparam_piwik_url AND substr($ciparam_piwik_url,-1)!='/')
        $ciparam_piwik_url .= '/';    
    
    return $ciparam_piwik_url;
}

function ciparam_piwik_id(){
    if (defined('_CIPARAM_PIWIK_ID') AND intval(_CIPARAM_PIWIK_ID)>0)
        $ciparam_piwik_id = _CIPARAM_PIWIK_ID;
    else
        $ciparam_piwik_id = ciparam_lire_meta('ci_piwik_id');

    return intval($ciparam_piwik_id);
}

// Liste des marqueurs de statistique actifs
// Exemples : 'xiti', 'piwik', 'xiti,piwik', 'piwik,xiti'
function ciparam_liste_marqueurs(){
    static $liste=null;
    
    if (is_null($liste)) {
        $liste = '';

        if (ciparam_xiti_actif()){
            $liste = 'xiti';
        }
        if (ciparam_piwik_actif()){
            $liste = ($liste ? ',' : '') . 'piwik';
        }
    }
    
    return $liste;
}

// Retourne le prefixe du squelette marqueur de statistique à utiliser
// Exemples : 'compteur', 'xiti', 'piwik', 'xitipiwik', ...
// Si aucun outil de statistique n'est actif, retourne ''
function ciparam_prefixe_squelette_marqueur() {
    static $prefixe=null;
    
    if (is_null($prefixe)) {
        $prefixe = '';

        if (ciparam_xiti_actif()){
            $prefixe = 'xiti';
        }
        if (ciparam_piwik_actif()){
            $prefixe .= 'piwik';
        }
    }

    return $prefixe;
}


/*-----------------------------------------------------------------
// Sommaire a plat d'un article
// Pour pouvoir utiliser sous SPIP 2.1 le plugin sommaire automatique
------------------------------------------------------------------*/

// Deux filtres
function ciparam_sommaireplat_article($texte,$select=false) {
//	return sommaire_empile_note().ciparam_affiche_sommaire($texte,$select).sommaire_depile_note();
	if (!defined('_DIR_PLUGIN_SOMMAIRE'))
		include_spip('inc/inc_plugin_sommaire');

    // Ajout CI pour �viter la duplication des notes de bas de page
	$GLOBALS["les_notes"] = "";
	$GLOBALS["compt_note"] = 0;
	$GLOBALS["marqueur_notes"] = 0;
		
	return ciparam_affiche_sommaire($texte,$select);
}

function ciparam_sommaireplat_ancre($texte){
	if (!defined('_DIR_PLUGIN_SOMMAIRE'))
		include_spip('inc/inc_plugin_sommaire');
	
	return ciparam_sommaire_post_propre(retire_sommaire($texte), false);
}

function ciparam_affiche_sommaire($texte,$select=false){return ciparam_sommaire_post_propre(retire_sommaire($texte),true,true,$select);}

function ciparam_sommaire_post_propre($texte, $ajoute=true, $sommaire_seul=false,$select=false){
	if ($texte AND strpos($texte, '<h')!==false){
		$texte = sommaire_filtre_texte_echappe($texte,'ciparam_sommaire_filtre'.($select ? '_select' : ''),'html|code|cadre|frame|script|acronym|cite',array($ajoute,$sommaire_seul));
        } elseif($sommaire_seul){
            return "";
        }
	return $texte;
}

function ciparam_sommaire_filtre($texte, $ajoute=true, $sommaire_seul=false){
	$sommaire = sommaire_recenser($texte);
        $res = '';
        
	if (!empty($texte) AND ($ajoute OR $sommaire_seul)){
		include_spip('inc/texte');
		
		//---- Debut ajout CI pour compatibilite SPIP 2.1 -----
		$debut = '<a name="nav-sommaire"></a><div class="well nav-sommaire nav-sommaire-'.count($sommaire).'">'	
				.'<h2>'._T('ciparam:titre_cadre_sommaire').'</h2>';
		$fin = '</div>';
		
		// le retour a la ligne est indispensable
		foreach ($sommaire AS $ligne){
			$res .= '
-'.str_pad('*',$ligne['niveau'],'*').' ['.$ligne['id'].'<-]['.$ligne['titre'].'->'.$ligne['href'].']';
		}

		$sommaire = "<!--sommaire-->" . $debut . propre($res) .$fin . "<!--/sommaire-->"; 

		if ($sommaire_seul)
			return $sommaire;
		if ($p = strpos($texte,"<sommaire>") OR $p = strpos($texte,"[sommaire]")){
			$texte = substr_replace($texte,$sommaire,$p,strlen("<sommaire>"));
		}
		else
			$texte = $sommaire . $texte;
	}
	return $texte;
}

function ciparam_sommaire_filtre_select($texte, $ajoute=true, $sommaire_seul=false){
	static $nb = 0;
	$nb++;
	$sommaire = sommaire_recenser($texte);

	if ($ajoute OR $sommaire_seul){
		include_spip('inc/texte');
		
		//---- Debut ajout CI pour compatibilite SPIP 2.1 -----
		if ($nb<2)
			$ancre = '<a name="nav-sommaire"></a>';
		else
			$ancre = '';

		$debut = $ancre.'<form name="accestitre'.$nb.'" action="Javascript:goToSelectURL(\'accestitre'.$nb.'\',\'nom_titre'.$nb.'\');" '
				.'method="get" class="nav-sommaire-'.count($sommaire).'">'
                                .'<label for="nom_titre'.$nb.'" class="texte">'._T('ciparam:acces_direct').' </label>'
				.'<select name="nom_titre'.$nb.'" id="nom_titre'.$nb.'">'
				.'<option value="" selected="selected">&nbsp;</option>';
		$fin = '</select><input type="submit" name="masquable" title="'._T('ciparam:atteindre_section').'" value="OK"></input></form>';
		
		
		foreach ($sommaire AS $ligne){
	        // met au passage des espaces insecables
	        if ($ligne['niveau']>=1)
		        $identation = 2*($ligne['niveau']-1);
		    else
		        $identation = 0;

			$res .= '<option value="'.$ligne['href'].'">'.str_pad('',$identation,'-').str_replace(' ','&nbsp;',$ligne['titre']).'</option>';
		}
		
		return "<!--sommaire-->" . $debut . $res .$fin . "<!--/sommaire-->"; 
	}
	return '';
}


/*-----------------------------------------------------------------
// Fonction pour les retours et les sauts de ligne multiples
------------------------------------------------------------------*/

// ciparam_post_autobr : transforme les retour a la ligne en _
// en tenant compte de certains cas particuliers
// et permet les sauts de ligne multiples
function ciparam_post_autobr($texte, $delim="\n_ ") {
        if (empty($texte)){
            return '';
        }
    
        if (!defined('_CIPARAM_POESIE')){
            define('_CIPARAM_POESIE', ",<(poesie|poetry)>(.*)<\/(poesie|poetry)>,UimsS");
        }
        
        $texte = str_replace("\r\n", "\r", $texte);
        $texte = str_replace("\r", "\n", $texte);

        // sauts de ligne consecutifs
        $texte = ciparam_sauts_lignes_consecutifs($texte);

        return $texte;

}

// sauts de ligne consecutifs (jusqu'a 5)
function ciparam_sauts_lignes_consecutifs($texte) {
        if (empty($texte)){
            return '';
        }

	$ci_sauts_lignes = ciparam_lire_meta("ci_sauts_lignes");		
	
	if ($ci_sauts_lignes=='oui' AND strpos($texte,"\n\n\n")!==false){
		$prefixe = "\n\n";
		$a = "\n";
		// l'espace au debut est indispensable
		$b = " <br class='autobr' />";
		// 5 sauts de ligne
		$texte = str_replace($prefixe.$a.$a.$a.$a,$prefixe.$b.$b.$b.$b, $texte);
		// 4 sauts de ligne
		$texte = str_replace($prefixe.$a.$a.$a,$prefixe.$b.$b.$b, $texte);
		// 3 sauts de ligne
		$texte = str_replace($prefixe.$a.$a,$prefixe.$b.$b, $texte);
		// 2 sauts de ligne
		$texte = str_replace($prefixe.$a,$prefixe.$b, $texte);
		
		// eviter un effet de bord avec les tableaux, les listes a puces, les listes numerotees, les lignes de separation
		$texte = str_replace(array($b.'|',$b.'-*',$b.'-#',$b.'----'),array($a.'|',$a.'-*',$a.'-#',$a.'----'), $texte);
	}
		
	return $texte;
}


/*-----------------------------------------------------------------
// Divers
------------------------------------------------------------------*/

function ciparam_monitoring_forme_rac($valeur='') {
	$texte = "";
	$objets_forme = array('articles', 'rubriques');
	$objets_rac = array('articles', 'rubriques','syndic');
	
	foreach ($objets_forme AS $objet) {
		$table = "spip_".$objet;
		$texte .= "<h2>formes-".$objet."</h2>";
		// uniquement les formes d'objets non archive et pas a la poubelle
		$req_where = sql_in('statut', array('poubelle','archive'),'NOT');
		$res = sql_allfetsel("COUNT(*) as cnt, ciforme", $table, $req_where, "ciforme");
		foreach($res as $row){
			if ($row['ciforme'])
				$texte .= "<p>".$row['ciforme']." (".$row['cnt'].")</p>";
		}
	}

	foreach ($objets_rac AS $objet) {
		$table = "spip_ci_raccourcis_".$objet;
		if ($objet=='syndic')
			$objet_au_singulier = $objet;
		else
			$objet_au_singulier = substr($objet,0,-1);
			
		$nom_id = "id_".$objet_au_singulier;
		$texte .= "<h2>raccourcis-".$objet."</h2>";
		// uniquement les raccourcis d'objets non archive et pas a la poubelle
		$req_where = sql_in('lien.statut', array('poubelle','archive'),'NOT');
		$res = sql_allfetsel("COUNT(*) as cnt, matable.raccourci", $table." as matable,spip_".$objet." as lien", "matable.".$nom_id."=lien.".$nom_id." AND ".$req_where, "raccourci");
		foreach($res as $row){
			$texte .= "<p>".$row['raccourci']." (".$row['cnt'].")</p>";
		}
	}
	
	return $texte;  
}	

function ciparam_article_raccourci($id_article=0,$raccourci=''){
	return ciparam_objet_raccourci('article',$id_article,$raccourci);
}

function ciparam_rubrique_raccourci($id_rubrique=0,$raccourci=''){
	return ciparam_objet_raccourci('rubrique',$id_rubrique,$raccourci);
}

function ciparam_objet_raccourci($objet,$id_objet=0,$raccourci=''){
	static $tableau_raccourci_ids_objet = array();
	$return = '';
	$id_objet = intval($id_objet);
	
	// le raccourci doit etre alphanumerique (avec possibilite underscore ou tiret)
	$raccourci_ok = false;
        if (!empty($raccourci)){
                if (ctype_alnum(str_replace(array("_",'-'),'',$raccourci))){
                        $raccourci_ok = true;
                }
        }
	if ($id_objet>0 AND $raccourci_ok AND in_array($objet, array('article','rubrique'))){

		$table = "spip_ci_raccourcis_".$objet."s";
		$nom_id = "id_".$objet;
		$objet_raccourci = $objet.'/'.$raccourci;
	
		if (!isset($tableau_raccourci_ids_objet[$objet_raccourci])){
			// memoriser en static si volumetrie raisonnable, sinon mettre "non"
			if (sql_countsel($table, "raccourci=".sql_quote($raccourci))<50){
				$ids = array();
				$result = sql_select($nom_id,$table,"raccourci=".sql_quote($raccourci));
				while ($row = sql_fetch($result))
					$ids[] = $row[$nom_id];

				$tableau_raccourci_ids_objet[$objet_raccourci] = $ids;
			} else {
				$tableau_raccourci_ids_objet[$objet_raccourci] = "non";
			}
		}

		if (is_array($tableau_raccourci_ids_objet[$objet_raccourci])){
			if (in_array($id_objet,$tableau_raccourci_ids_objet[$objet_raccourci])){
				$return = "oui";
			}
		} else {
			if (sql_countsel($table, $nom_id.'='.$id_objet." AND raccourci=".sql_quote($raccourci))>=1) {	
				$return = "oui";
			}			
		}		
	}

	return $return;
}

function ciparam_menu_spip_out($id_rubrique=0){
	$return = "";
	if (ciparam_objet_raccourci('rubrique',$id_rubrique,'_nouvelle_fenetre')=="oui")
		$return = " spip_out";
	
	return $return;
}

function ciparam_sans_p($texte){
        if (empty($texte)){
            return '';
        }
	if (substr($texte,0,3)=="<p>" AND substr($texte,-4)=="</p>")
		return substr($texte,3,-4);
	else 
		return $texte;
}


/*-----------------------------------------------------------------
// Filtre du menu de navigation (aiguillage)
------------------------------------------------------------------*/
// Construit le menu de navigation (volumetrie rubrique)
// Renvoi le  menu de navigation a partir de 3 tableaux des rubriques concernees
// Chaque ligne des tableaux passes en parametre de la fonction doit comprendre
// #ARRAY{id_parent,#ID_PARENT,id_rubrique,#ID_RUBRIQUE,titre,#TITRE}

// Exemple d'utilisation dans un squelette :
/*
<BOUCLE_masquer(RUBRIQUES){raccourci=_masquer_dans_menu_dynamique}{doublons}{par id_rubrique}></BOUCLE_masquer>
#SET{cirub_niv1, #ARRAY{}}
#SET{ciwhere_niv1, #ARRAY{}}
<BOUCLE_niv1(RUBRIQUES){id_parent=0}{doublons}{par id_parent}{par num titre}>[(#SET{cirub_niv1, #GET{cirub_niv1}|push{#ARRAY{id_parent,#ID_PARENT,id_rubrique,#ID_RUBRIQUE,titre,#TITRE}}})][(#SET{ciwhere_niv1, #GET{ciwhere_niv1}|push{#ID_RUBRIQUE}})]</BOUCLE_niv1>
#SET{cirub_niv2, #ARRAY{}}
#SET{ciwhere_niv2, #ARRAY{}}
<BOUCLE_niv2(RUBRIQUES){id_parent IN #GET{ciwhere_niv1}}{doublons}{par id_parent}{par num titre}>[(#SET{cirub_niv2, #GET{cirub_niv2}|push{#ARRAY{id_parent,#ID_PARENT,id_rubrique,#ID_RUBRIQUE,titre,#TITRE}}})][(#SET{ciwhere_niv2, #GET{ciwhere_niv2}|push{#ID_RUBRIQUE}})]</BOUCLE_niv2>
#SET{cirub_niv3, #ARRAY{}}
<BOUCLE_niv3(RUBRIQUES){id_parent IN #GET{ciwhere_niv2}}{doublons}{par id_parent}{par num titre}>[(#SET{cirub_niv3, #GET{cirub_niv3}|push{#ARRAY{id_parent,#ID_PARENT,id_rubrique,#ID_RUBRIQUE,titre,#TITRE}}})]</BOUCLE_niv3>

<nav role="navigation" aria-label="Menu principal">
[(#GET{cirub_niv1}|ciparam_menu{#GET{cirub_niv2},#GET{cirub_niv3}})]
</nav>
*/
function ciparam_menu($cirub_niv1,$cirub_niv2,$cirub_niv3,$variante=''){
	$citextemenu = "";

   	$ci_menu_type = ciparam_menu_type();
        
        if ($ci_menu_type=="smartmenu"){
                $citextemenu = ciparam_smartmenu($cirub_niv1,$cirub_niv2,$cirub_niv3,$variante);
        } else if ($ci_menu_type=="megamenu"){
                $citextemenu = ciparam_megamenu($cirub_niv1,$cirub_niv2,$cirub_niv3,$variante);
        } else if ($ci_menu_type=="superfish"){
                $citextemenu = ciparam_superfish($cirub_niv1,$cirub_niv2,$cirub_niv3,$variante);
        }
        
	return $citextemenu;  
}


// Type de menu (dans la configuration)
function ciparam_menu_type($texte=''){
   	$ci_menu_type = ciparam_lire_meta("ci_menu_type");
	if (!$ci_menu_type) $ci_menu_type = "smartmenu";

        // Parametrage par constante dans un fichier d'options
	if (defined("_CIPARAM_MENU_TYPE") AND in_array(_CIPARAM_MENU_TYPE, array("smartmenu","megamenu","superfish")))
		$ci_menu_type = _CIPARAM_MENU_TYPE;
        
	return $ci_menu_type;  
}

/*-----------------------------------------------------------------
// menu superfish
------------------------------------------------------------------*/
function ciparam_superfish($cirub_niv1,$cirub_niv2,$cirub_niv3,$variante=''){
	$texte = "";
	$secteur=0;
	$niv2existe = false;
	$niv3existe = false;
	$cin1n2 = array();
	$cin2n3 = array();
	$premier_n1 = true;
	$premier_n2 = true;
	$premier_n3 = true;
	$compteur1 = 0;

	// Nombre de niveau parametres
   	$ci_menu_niveau = ciparam_lire_meta("ci_menu_niveau");
	if (!$ci_menu_niveau) $ci_menu_niveau = "3";

        if ($ci_menu_niveau=="1"){
                $cirub_niv2 = array();
                $cirub_niv3 = array();
        }
        if ($ci_menu_niveau=="2"){
                $cirub_niv3 = array();
        }
        
	if ($ci_menu_niveau != "1" AND $cirub_niv2 AND is_array($cirub_niv2)) {
		$niv2existe = true;
	 	foreach($cirub_niv2 as $row_niv2) {
	 		$cin1n2[$row_niv2['id_rubrique']] = $row_niv2['id_parent'];
	 	}
	 	reset($cirub_niv2);
	}
        
	if ($ci_menu_niveau == "3" AND $cirub_niv3 AND is_array($cirub_niv3)) {
		$niv3existe = true;
	 	foreach($cirub_niv3 as $row_niv3) {
	 		$cin2n3[$row_niv3['id_rubrique']] = $row_niv3['id_parent'];
	 	}
	 	reset($cirub_niv3);
	}
        
        foreach ($cirub_niv1 as $row1) {			
                $rub_n1 = $row1['id_rubrique'];
                $titre_n1 = $row1['titre'];
                $premier_n2 = true;
                $compteur1++;
                
                if ($premier_n1){
                    $texte .= '<div id="menuhorizontal" tabindex="-1">';
                    $texte .= '<div id="menuprincipal-sf">';
                    $texte .= '<ul id="menu" class="menu">';
                    $texte .= '<li class="mnu_id0 rub_niv0 li_mnu0"><a href="'.generer_url_public("sommaire").'">'._T('cisquel:eq_accueil').'</a></li>';
                    $premier_n1 = false;
                }
                
		$texte .= '<li id="cimenu'.$rub_n1.'" class="mnu_id'.$compteur1.' rub_niv0"><a class="'.ciparam_menu_spip_out($rub_n1).'" href="'.ciparam_generer_url($rub_n1,"rubrique").'">'.supprimer_numero(interdire_scripts(typo(trim($titre_n1)))).'</a>';			
                
                if ($niv2existe AND in_array($rub_n1,$cin1n2)) {
                        foreach ($cirub_niv2 as $row2) {			
                                $parent_n2 = $row2['id_parent'];
                                if ($parent_n2==$rub_n1){
                                        $rub_n2 = $row2['id_rubrique'];
                                        $titre_n2 = $row2['titre'];
                                        $premier_n3 = true;

                                        if ($premier_n2){
                                            $texte .= '<ul class="niveau2 sousmnu_'.$compteur1.'">';
                                            $premier_n2 = false;
                                        }

                                        $texte .= '<li><a class="'.ciparam_menu_spip_out($rub_n2).'" href="'.ciparam_generer_url($rub_n2,"rubrique").'">'.supprimer_numero(interdire_scripts(typo(trim($titre_n2)))).'</a>';			

                                        if ($niv3existe AND in_array($rub_n2,$cin2n3)) {
                                                foreach ($cirub_niv3 as $row3) {			
                                                        $parent_n3 = $row3['id_parent'];
                                                        if ($parent_n3==$rub_n2){
                                                            $rub_n3 = $row3['id_rubrique'];
                                                            $titre_n3 = $row3['titre'];

                                                            if ($premier_n3){
                                                                $texte .= '<span class="fleche_sous_menu"></span>';
                                                                $texte .= '<ul class="niveau3 sousmnu_'.$compteur1.'">';
                                                                $premier_n3 = false;
                                                            }

                                                            $texte .= '<li><a class="'.ciparam_menu_spip_out($rub_n3).'" href="'.ciparam_generer_url($rub_n3,"rubrique").'">'.supprimer_numero(interdire_scripts(typo(trim($titre_n3)))).'</a></li>';
                                                        }
                                                }
                                                if (!$premier_n3)
                                                        $texte .= '</ul>';
                                        }
                                        $texte .= '</li>';
                                }
                        }
                        if (!$premier_n2)
                                $texte .= '</ul>';

                }
                $texte .= '</li>';
        }
        
        if (!$premier_n1)
                $texte .= '</ul></div></div>';
        
	return $texte;  
}


/*-----------------------------------------------------------------
// mega menu
------------------------------------------------------------------*/
function ciparam_megamenu($cirub_niv1,$cirub_niv2,$cirub_niv3,$variante=''){
	$texte = "";
	$secteur=0;
        $id_parent = 0;
	$niv2existe = false;
	$niv3existe = false;
	$cin1n2 = array();
	$cin2n3 = array();
	$premier_n1 = true;
	$premier_n2 = true;
	$premier_n3 = true;
	$compteur1 = 0;
        $compteur2 = 0;
        $class_n2 = '';
        $class_n3 = '';
	$ci_nb_items_par_bloc_n2 = array();
	$ci_nb_n2_par_colonne = array();
	$ci_nb_items_bloc_n2 = 0;
        $colonne = 1;
        $lib_affiche_theme = _T('ciparam:afficher_le_theme');

	// Nombre de niveau parametres
   	$ci_menu_niveau = ciparam_lire_meta("ci_menu_niveau");
	if (!$ci_menu_niveau) $ci_menu_niveau = "3";

        if ($ci_menu_niveau=="1"){
                $cirub_niv2 = array();
                $cirub_niv3 = array();
        }
        if ($ci_menu_niveau=="2"){
                $cirub_niv3 = array();
        }
        
        // Determination du nombre d'items de niveau 2 par colonne
	if ($ci_menu_niveau != "1" AND $cirub_niv2 AND is_array($cirub_niv2)) {
		$niv2existe = true;
	 	foreach($cirub_niv2 as $row_niv2) {
                        // On passe au parent suivant
                        if ($id_parent != $row_niv2['id_parent']){
                            if ($id_parent>0){
                                $ci_nb_n2_par_colonne[$id_parent] = ci_repartition_par_colonne($ci_nb_items_par_bloc_n2);
                                $ci_nb_items_par_bloc_n2 = array();
                            }
                            $id_parent = $row_niv2['id_parent'];
                        }
                    
	 		$ci_nb_items_bloc_n2 = 1;
	 		$cin1n2[$row_niv2['id_rubrique']] = $row_niv2['id_parent'];
                	if ($ci_menu_niveau == "3" AND $cirub_niv3 AND is_array($cirub_niv3)) {
                            foreach($cirub_niv3 as $row_niv3) {
                                    if ($row_niv3['id_parent']==$row_niv2['id_rubrique']){
                                        $ci_nb_items_bloc_n2++;
                                    }
                            }
                            reset($cirub_niv3);
                        }
                        $ci_nb_items_par_bloc_n2[] = $ci_nb_items_bloc_n2;
	 	}
                
                // memoriser le dernier
                if ($id_parent>0){
                    $ci_nb_n2_par_colonne[$id_parent] = ci_repartition_par_colonne($ci_nb_items_par_bloc_n2);
                }
	 	reset($cirub_niv2);
	}
        
	if ($ci_menu_niveau == "3" AND $cirub_niv3 AND is_array($cirub_niv3)) {
		$niv3existe = true;
	 	foreach($cirub_niv3 as $row_niv3) {
	 		$cin2n3[$row_niv3['id_rubrique']] = $row_niv3['id_parent'];
	 	}
	 	reset($cirub_niv3);
	}
        
        foreach ($cirub_niv1 as $row1) {			
                $rub_n1 = $row1['id_rubrique'];
                $titre_n1 = $row1['titre'];
                $premier_n2 = true;
                $compteur1++;
                $colonne = 1;
                $compteur2=0;
                
                if ($premier_n1){
                    $texte .= '<div class="cimenumobile-btn-container"><a role="button" href="#" id="cimenumobile-btn" aria-controls="menuhorizontal" class="cimenumobile-btn">'._T('ciparam:eq_menu').'<span class="cimenumobile-icon"></span></a></div>';    
                    $texte .= '<div id="menuhorizontal" class="mobilereplie" tabindex="-1">';
                    $texte .= '<div class="cimenu-table"><ul class="cimenu-ul-theme">';
                    $texte .= '<li class="cimenu-li-theme"><a href="'.generer_url_public("sommaire").'" class="cimenu-theme cimenu-home">'._T('cisquel:eq_accueil').'</a></li>';
                    $premier_n1 = false;
                }
                
                
                if ($niv2existe AND in_array($rub_n1,$cin1n2)) {
                        $texte .= '<li id="cimenu'.$rub_n1.'" class="cimenu-li-theme">
                                    <a role="button" href="'.ciparam_generer_url($rub_n1,"rubrique").'" id="cimenu-'.$compteur1.'-btn" aria-controls="cimenu-'.$compteur1.'" class="cimenu-theme'.ciparam_menu_spip_out($rub_n1).'">'.supprimer_numero(interdire_scripts(typo(trim($titre_n1)))).'</a>
                                    <div id="cimenu-'.$compteur1.'" class="cimenu-sous-themes replie">
                                    <p class="close"><button title="Fermer le menu" aria-controls="cimenu-'.$compteur1.'" type="button" class="btn-close">Fermer</button></p>
                                    <div role="list" class="cimenu-sous-themes-inner">
                                    <div class="cimenu-colonne">';
                
                        foreach ($cirub_niv2 as $row2) {
                                $parent_n2 = $row2['id_parent'];
                                $premier = '';
                                if ($parent_n2==$rub_n1){
                                        $rub_n2 = $row2['id_rubrique'];
                                        $titre_n2 = $row2['titre'];
                                        $premier_n3 = true;
                                        
                                        // changement de colonne ?
                                        $compteur2++;
                                        if (isset($ci_nb_n2_par_colonne[$parent_n2][$colonne]) AND $compteur2 > $ci_nb_n2_par_colonne[$parent_n2][$colonne]){
                                            $texte .= '</div><div class="cimenu-colonne">';
                                            $colonne++;
                                            $compteur2 = 1; // important
                                        }
                                        if ($compteur2 == 1)
                                            $premier = ' premier';
                                        
                                        $class_n2 = ciparam_menu_spip_out($rub_n2);
                                        if ($class_n2)
                                            $class_n2 = ' class="'.$class_n2.'"';

                                        $texte .= '<div role="listitem" class="cimenu_theme_n2'.$premier.'">
                                                    <p><a class="cimenu-item" href="'.ciparam_generer_url($rub_n2,"rubrique").'"'.$class_n2.'>'.supprimer_numero(interdire_scripts(typo(trim($titre_n2)))).'</a></p>';

                                        if ($niv3existe AND in_array($rub_n2,$cin2n3)) {
                                                foreach ($cirub_niv3 as $row3) {			
                                                        $parent_n3 = $row3['id_parent'];
                                                        if ($parent_n3==$rub_n2){
                                                            $rub_n3 = $row3['id_rubrique'];
                                                            $titre_n3 = $row3['titre'];

                                                            if ($premier_n3){
                                                                $texte .= '<ul>';
                                                                $premier_n3 = false;
                                                            }
                                                            
                                                            $class_n3 = ciparam_menu_spip_out($rub_n3);
                                                            if ($class_n3)
                                                                $class_n3 = ' class="'.$class_n3.'"';

                                                            $texte .= '<li><a class="cimenu-item"'.$class_n3.' href="'.ciparam_generer_url($rub_n3,"rubrique").'">'.supprimer_numero(interdire_scripts(typo(trim($titre_n3)))).'</a></li>';			
                                                        }
                                                }
                                                if (!$premier_n3)
                                                        $texte .= '</ul>';
                                        }
                                        $texte .= '</div>';
                                }
                        }
                        $texte .= '</div>';
                        $texte .= '<p class="lien-theme"><a href="'.ciparam_generer_url($rub_n1,"rubrique").'" class="cimenu-lien-theme'.ciparam_menu_spip_out($rub_n1).'">'.$lib_affiche_theme.' : '.supprimer_numero(interdire_scripts(typo(trim($titre_n1)))).'</a></p>';
                        $texte .= '</div></div>';

                } else {
        		$texte .= '<li id="cimenu'.$rub_n1.'" class="cimenu-li-theme"><a class="cimenu-theme'.ciparam_menu_spip_out($rub_n1).'" href="'.ciparam_generer_url($rub_n1,"rubrique").'">'.supprimer_numero(interdire_scripts(typo(trim($titre_n1)))).'</a>';			
                }
                $texte .= '</li>';
        }
        
        if (!$premier_n1)
                $texte .= '</ul></div></div>';
        
	return $texte;  
}

function ci_repartition_par_colonne($ci_nb_items_par_bloc_n2){
	$ci_nb_colonnes = 4;
        $num_colonne = 1;
        $ci_nombre_n2 = 0;
	$ci_cumul_nb_items = 0;
	$ci_max_items_par_bloc_n2 = 0;
	$ci_nb_total_items = 0;
	$ci_nb_items_par_colonne = 0;
	$return = array();
        
        if ($ci_nb_items_par_bloc_n2 AND is_array($ci_nb_items_par_bloc_n2)){
                $ci_nb_total_items = array_sum($ci_nb_items_par_bloc_n2);
                $ci_max_items_par_bloc_n2 = max($ci_nb_items_par_bloc_n2);
                $ci_nb_items_par_colonne = ceil($ci_nb_total_items / $ci_nb_colonnes);
                
                // si un bloc n2 a plus d'items que le nombre prevu par colonne alors ajuster
                if ($ci_max_items_par_bloc_n2 > $ci_nb_items_par_colonne){
                    $ci_nb_items_par_colonne = $ci_max_items_par_bloc_n2;
                }
                
                // si le max item par bloc n2 est 1 alors tout mettre sur une seule colonne
//                elseif ($ci_max_items_par_bloc_n2 < 2){
//                    $ci_nb_items_par_colonne = $ci_nb_total_items;
//                }
                
                // on essaye une repartition avec $ci_nb_items_par_colonne :
                // on affecte les niveaux 2 à la col1 sans depasser $ci_nb_items_par_colonne puis on passe a la col2, etc.
                // On note le nombre de n2 par colonne dans le tableau $return.
                // Si cela depasse dans une colonne (la derniere), on essaye avec $ci_nb_items_par_colonne+1
                // puis $ci_nb_items_par_colonne+2, etc.
                $ok = false;
                while (!$ok){
                        foreach($ci_nb_items_par_bloc_n2 as $nombre) {
                            if ( ($ci_cumul_nb_items + $nombre) > $ci_nb_items_par_colonne){
                                $return[$num_colonne] = $ci_nombre_n2;
                                $num_colonne++;
                                $ci_nombre_n2 = 0;
                                $ci_cumul_nb_items = 0;
                            }
                            $ci_nombre_n2++;
                            $ci_cumul_nb_items += $nombre;
                        }
                        
                        // memoriser la derniere colonne
                        $return[$num_colonne] = $ci_nombre_n2;
                        
                        // Si cela depasse dans une colonne (la derniere)
                        if (max($return)>$ci_nb_items_par_colonne){
                            // incrementer
                            $ci_nb_items_par_colonne++;
                            // reinitialiser
                            $return = array();
                            $num_colonne = 1;
                            $ci_nombre_n2 = 0;
                            $ci_cumul_nb_items = 0;
                            reset($ci_nb_items_par_bloc_n2);
                        } else {
                            $ok = true;
                        }
                }
        }
        return $return;
}

/*-----------------------------------------------------------------
// smartmenu
------------------------------------------------------------------*/
function ciparam_smartmenu($cirub_niv1,$cirub_niv2,$cirub_niv3,$variante=''){
	$texte = "";
	$secteur=0;
	$niv2existe = false;
	$niv3existe = false;
	$cin1n2 = array();
	$cin2n3 = array();
	$premier_n1 = true;
	$premier_n2 = true;
	$premier_n3 = true;
	$compteur1 = 0;

	// Nombre de niveau parametres
   	$ci_menu_niveau = ciparam_lire_meta("ci_menu_niveau");
	if (!$ci_menu_niveau) $ci_menu_niveau = "3";

        if ($ci_menu_niveau=="1"){
                $cirub_niv2 = array();
                $cirub_niv3 = array();
        }
        if ($ci_menu_niveau=="2"){
                $cirub_niv3 = array();
        }
        
	if ($ci_menu_niveau != "1" AND $cirub_niv2 AND is_array($cirub_niv2)) {
		$niv2existe = true;
	 	foreach($cirub_niv2 as $row_niv2) {
	 		$cin1n2[$row_niv2['id_rubrique']] = $row_niv2['id_parent'];
	 	}
	 	reset($cirub_niv2);
	}
        
	if ($ci_menu_niveau == "3" AND $cirub_niv3 AND is_array($cirub_niv3)) {
		$niv3existe = true;
	 	foreach($cirub_niv3 as $row_niv3) {
	 		$cin2n3[$row_niv3['id_rubrique']] = $row_niv3['id_parent'];
	 	}
	 	reset($cirub_niv3);
	}
        
        foreach ($cirub_niv1 as $row1) {			
                $rub_n1 = $row1['id_rubrique'];
                $titre_n1 = $row1['titre'];
                $premier_n2 = true;
                $compteur1++;
                
                if ($premier_n1){
                    $texte .= '<div id="menuhorizontal" tabindex="-1">';
                    $texte .= '<input id="main-menu-state" type="checkbox" />'
                            .'<label class="main-menu-btn" for="main-menu-state"><span class="main-menu-btn-icon"></span> Toggle main menu visibility</label>'
                            .'<ul id="main-menu" class="sm sm-blue">';
                    $texte .= '<li class="liniv1"><a href="'.generer_url_public("sommaire").'" class="niv1">'._T('cisquel:eq_accueil').'</a></li>';
                    $premier_n1 = false;
                }

                if (defined('_CI_SEN') AND _CI_SEN=='oui'){
                    $texte .= '<li id="cimenu'.$rub_n1.'" class="liniv1"><a class="niv1'.ciparam_menu_spip_out($rub_n1).'" href="'.ciparam_generer_url($rub_n1,"rubrique").'"><span class="menutitre">'.supprimer_numero(interdire_scripts(typo(trim($titre_n1)))).'</span></a>';
                } else {                
                    $texte .= '<li id="cimenu'.$rub_n1.'" class="liniv1"><a class="niv1'.ciparam_menu_spip_out($rub_n1).'" href="'.ciparam_generer_url($rub_n1,"rubrique").'">'.supprimer_numero(interdire_scripts(typo(trim($titre_n1)))).'</a>';
                }

                if ($niv2existe AND in_array($rub_n1,$cin1n2)) {
                        foreach ($cirub_niv2 as $row2) {			
                                $parent_n2 = $row2['id_parent'];
                                if ($parent_n2==$rub_n1){
                                        $rub_n2 = $row2['id_rubrique'];
                                        $titre_n2 = $row2['titre'];
                                        $premier_n3 = true;

                                        if ($premier_n2){
                                            $texte .= '<ul>';
                                            $premier_n2 = false;
                                        }

                                        $texte .= '<li><a class="'.ciparam_menu_spip_out($rub_n2).'" href="'.ciparam_generer_url($rub_n2,"rubrique").'">'.supprimer_numero(interdire_scripts(typo(trim($titre_n2)))).'</a>';			

                                        if ($niv3existe AND in_array($rub_n2,$cin2n3)) {
                                                foreach ($cirub_niv3 as $row3) {			
                                                        $parent_n3 = $row3['id_parent'];
                                                        if ($parent_n3==$rub_n2){
                                                            $rub_n3 = $row3['id_rubrique'];
                                                            $titre_n3 = $row3['titre'];

                                                            if ($premier_n3){
                                                                $texte .= '<ul>';
                                                                $premier_n3 = false;
                                                            }

                                                            $texte .= '<li><a class="'.ciparam_menu_spip_out($rub_n3).'" href="'.ciparam_generer_url($rub_n3,"rubrique").'">'.supprimer_numero(interdire_scripts(typo(trim($titre_n3)))).'</a></li>';
                                                        }
                                                }
                                                if (!$premier_n3)
                                                        $texte .= '</ul>';
                                        }
                                        $texte .= '</li>';
                                }
                        }
                        if (!$premier_n2)
                                $texte .= '</ul>';

                }
                $texte .= '</li>';
        }
        
        if (!$premier_n1)
                $texte .= '</ul></div>';
        
	return $texte;  
}


// Ajouter possibilite que les articles sans logo heritent du logo de leur rubrique
function balise_LOGO_($p) {

	preg_match(",^LOGO_([A-Z_]+?)(|_NORMAL|_SURVOL|_RUBRIQUE)$,i", $p->nom_champ, $regs);
	$type = strtolower($regs[1]);
	$suite_logo = $regs[2];
        
        // Debut ajout CI
        if ($type=='article' AND !$suite_logo)
        	$suite_logo = '_RUBRIQUE';
        // Fin ajout CI

	// cas de #LOGO_SITE_SPIP
	if ($type == 'site_spip') {
		$type = 'site';
		$_id_objet = "\"'0'\"";
	}

	$id_objet = id_table_objet($type);
	if (!isset($_id_objet) OR !$_id_objet)
		$_id_objet = champ_sql($id_objet, $p);

	$fichier = ($p->etoile === '**') ? -1 : 0;
	$coord = array();
	$align = $lien = '';
	$mode_logo = '';

	if ($p->param AND !$p->param[0][0]) {
		$params = $p->param[0];
		array_shift($params);
		foreach($params as $a) {
			if ($a[0]->type === 'texte') {
				$n = $a[0]->texte;
				if (is_numeric($n))
					$coord[]= $n;
				elseif (in_array($n,array('top','left','right','center','bottom')))
					$align = $n;
				elseif (in_array($n,array('auto','icone','apercu','vignette')))
					$mode_logo = $n;
			}
			else $lien =  calculer_liste($a, $p->descr, $p->boucles, $p->id_boucle);

		}
	}

	$coord_x = !$coord  ? 0 : intval(array_shift($coord));
	$coord_y = !$coord  ? 0 : intval(array_shift($coord));
	
	if ($p->etoile === '*') {
		include_spip('balise/url_');
		$lien = generer_generer_url_arg($type, $p, $_id_objet);
	}

	$connect = $p->id_boucle ?$p->boucles[$p->id_boucle]->sql_serveur :'';
	if ($type == 'document') {
		$qconnect = _q($connect);
		$doc = "quete_document($_id_objet, $qconnect)";
		if ($fichier)
			$code = "quete_logo_file($doc, $qconnect)";
		else $code = "quete_logo_document($doc, " . ($lien ? $lien : "''") . ", '$align', '$mode_logo', $coord_x, $coord_y, $qconnect)";
		// (x=non-faux ? y : '') pour affecter x en retournant y
		if ($p->descr['documents'])
		  $code = '(($doublons["documents"] .= ",". '
		    . $_id_objet
		    . ") ? $code : '')";
	}
	elseif ($connect) {
		$code = "''";
		spip_log("Les logos distants ne sont pas prevus");
	} else {
		$code = ciparam_logo_survol($id_objet, $_id_objet, $type, $align, $fichier, $lien, $p, $suite_logo);
	}

	// demande de reduction sur logo avec ecriture spip 2.1 : #LOGO_xxx{200, 0}
	if ($coord_x OR $coord_y) {
		$code = "filtrer('image_graver',filtrer('image_reduire',".$code.", '$coord_x', '$coord_y'))"; 
	} 

	$p->code = $code;
	$p->interdire_scripts = false;
	return $p;
}

function ciparam_logo_survol($id_objet, $_id_objet, $type, $align, $fichier, $lien, $p, $suite)
{
	$code = "ciparam_quete_logo('$id_objet', '" .
		(($suite == '_SURVOL') ? 'off' : 
		(($suite == '_NORMAL') ? 'on' : 'ON')) .
		"', $_id_objet," .
		(($suite == '_RUBRIQUE') ? 
		champ_sql("id_rubrique", $p) :
		(($type == 'rubrique') ? "quete_parent($_id_objet)" : "''")) .
		", " . intval($fichier) . ")";

	if ($fichier) return $code;

        if ($GLOBALS['spip_version_branche']>=4){
            $align = preg_replace(",\W,", "", $align);

            return "quete_html_logo($code, '$align', " .($lien ? $lien : "''") .")";
            
        } else {
            $code = "\n((!is_array(\$l = $code)) ? '':\n (" .
                         '"<img class=\"spip_logos\" alt=\"\"' .
                        ($align ? " align=\\\"$align\\\"" : '')
                        . ' src=\"$l[0]\"" . $l[2] .  ($l[1] ? " onmouseover=\"this.src=\'$l[1]\'\" onmouseout=\"this.src=\'$l[0]\'\"" : "") . \' />\'))';

            if (!$lien) return $code;

            return ('(strlen($logo='.$code.')?\'<a href="\' .' . $lien . ' . \'">\' . $logo . \'</a>\':\'\')');
        }
}

function ciparam_quete_logo($type, $onoff, $id, $id_rubrique, $flag) {
    
    if ($GLOBALS['spip_version_branche']>=4){
        $cle_objet = $type;
        
	include_spip('base/objets');
	$nom = strtolower($onoff);

	while (1) {
		$objet = objet_type($cle_objet);

		$on = quete_logo_objet($id, $objet, $nom);

		if ($on) {
			if ($flag) {
				return basename($on['chemin']);
			} else {
				$taille = @getimagesize($on['chemin']);

				// Si on a déjà demandé un survol directement ($onoff = off)
				// ou qu'on a demandé uniquement le normal ($onoff = on)
				// alors on ne cherche pas du tout le survol ici
				if ($onoff != 'ON') {
					$off = '';
				} else {
					// Sinon, c'est qu'on demande normal ET survol à la fois, donc on cherche maintenant le survol
					$off = quete_logo_objet($id, $objet, 'off');
				}

				// on retourne une url du type IMG/artonXX?timestamp
				// qui permet de distinguer le changement de logo
				// et placer un expire sur le dossier IMG/
				$res = array(
					$on['chemin'] . ($on['timestamp'] ? "?{$on['timestamp']}" : ''),
					($off ? $off['chemin'] . ($off['timestamp'] ? "?{$off['timestamp']}" : '') : ''),
					(!$taille ? '' : (' ' . $taille[3]))
				);
				$res['src'] = $res[0];
				$res['logo_on'] = $res[0];
				$res['logo_off'] = $res[1];
				$res['width'] = ($taille ? $taille[0] : '');
				$res['height'] = ($taille ? $taille[1] : '');

				return $res;
			}
		} else {
                        // Debut ajout CI
                        // if (defined('_LOGO_RUBRIQUE_DESACTIVER_HERITAGE')) {
                        //        return '';
                        if (defined('_LOGO_RUBRIQUE_DESACTIVER_HERITAGE') 
                                AND ($type!='id_article' OR !ciparam_logo_article_heritage_actif($type, $id_rubrique))){
                                return '';
                        } else if (!defined('_LOGO_RUBRIQUE_DESACTIVER_HERITAGE') 
                                AND ($type=='id_article' AND !ciparam_logo_article_heritage_actif($type, $id_rubrique))){
                                return '';
                        // Fin ajout CI
			} else {
				if ($id_rubrique) {
					$cle_objet = 'id_rubrique';
					$id = $id_rubrique;
					$id_rubrique = 0;
				} else {
					if ($id and $cle_objet == 'id_rubrique') {
						$id = quete_parent($id);
					} else {
						return '';
					}
				}
			}
		}
	}
        
    } else {
	static $chercher_logo;
	if (is_null($chercher_logo))
		$chercher_logo = charger_fonction('chercher_logo', 'inc');
	$nom = strtolower($onoff);
	while (1) {
		$on = $chercher_logo($id, $type, $nom);
		if ($on) {
			if ($flag)
				return "$on[2].$on[3]";
			else {
				$taille = @getimagesize($on[0]);
				$off = ($onoff != 'ON') ? '' :
					$chercher_logo($id, $type, 'off');
				// on retourne une url du type IMG/artonXX?timestamp
				// qui permet de distinguer le changement de logo
				// et placer un expire sur le dossier IMG/
				return array ($on[0].($on[4]?"?$on[4]":""),
					($off ? $off[0] . ($off[4]?"?$off[4]":"") : ''),
					(!$taille ? '' : (" ".$taille[3])));
			}
		}
                // Debut ajout CI
                // else if (defined('_LOGO_RUBRIQUE_DESACTIVER_HERITAGE'))
                //        return '';
                else if (defined('_LOGO_RUBRIQUE_DESACTIVER_HERITAGE') 
                        AND ($type!='id_article' OR !ciparam_logo_article_heritage_actif($type, $id_rubrique)))
                        return '';
                else if (!defined('_LOGO_RUBRIQUE_DESACTIVER_HERITAGE') 
                        AND ($type=='id_article' AND !ciparam_logo_article_heritage_actif($type, $id_rubrique)))
                        return '';
                // Fin ajout CI
                else if ($id_rubrique) {
			$type = 'id_rubrique';
			$id = $id_rubrique;
			$id_rubrique = 0;
		} else if ($id AND $type == 'id_rubrique')
			$id = quete_parent($id);
		else return '';
	}
    }
}

function ciparam_logo_article_heritage_actif($type='', $id_rubrique=0) {
    static $tableau = array();
    $id_rubrique = intval($id_rubrique);
    $cle = $type.strval($id_rubrique);
    
    if (!isset($tableau[$cle])) {
        $tableau[$cle] = false;
    
        if ($type=='id_article' AND $id_rubrique>0 AND sql_countsel('spip_ci_raccourcis_rubriques', "id_rubrique=".intval($id_rubrique)." AND raccourci='_article_herite_logo_rubrique'")>=1){
            $tableau[$cle] = true;
        }
    }

    return $tableau[$cle];
}

function ciparam_datepicker_js($var){
    $return = '';
    $majeure = 0;
    $mineure = 0;
    $lang = 'fr';

    if (!empty($var)){
        if (ctype_alpha(str_replace('_','',$var))){
            $lang = $var;
        } 
    }
    
    // une exception
    if ($lang=='en'){
        $lang = 'en-GB';
    }
    
    $tableau_version = explode('.',$GLOBALS['spip_version_branche']);
    if (isset($tableau_version[0])){
        $majeure = intval($tableau_version[0]);
    }
    if (isset($tableau_version[1])){
        $mineure = intval($tableau_version[1]);
    }

    if ($majeure>=3){
        if (defined('_CIPARAM_SITE_PUBLIC_EN_JQUERY_UI_1_8_21') 
                AND _CIPARAM_SITE_PUBLIC_EN_JQUERY_UI_1_8_21=='oui' 
                AND $mineure>=1){
            // utiliser la version 1.8.21 de jQueryUI stockee dans ciparam (celle qu'utilise SPIP 3.0)  
            $return = '<script type="text/javascript" src="'.find_in_path('_js/ui_v108/jquery.ui.core.js').'"></script>
<script type="text/javascript" src="'.find_in_path('_js/ui_v108/jquery.ui.datepicker.js').'"></script>
<script type="text/javascript" src="'.find_in_path('_js/ui_v108/i18n/jquery.ui.datepicker-'.$lang.'.js').'"></script>';
            
        } elseif ($mineure>=2){
            // SPIP 3.2
            $return = '<script type="text/javascript" src="'.find_in_path('prive/javascript/ui/jquery-ui.js').'"></script>
<script type="text/javascript" src="'.find_in_path('prive/javascript/ui/i18n/datepicker-'.$lang.'.js').'"></script>';
        } else {
            // SPIP 3.0 ou SPIP 3.1
            $return = '<script type="text/javascript" src="'.find_in_path('prive/javascript/ui/jquery.ui.core.js').'"></script>
<script type="text/javascript" src="'.find_in_path('prive/javascript/ui/jquery.ui.datepicker.js').'"></script>
<script type="text/javascript" src="'.find_in_path('prive/javascript/ui/i18n/jquery.ui.datepicker-'.$lang.'.js').'"></script>';
        }
    } else {
        // SPIP 2.1 et moins
        $return = '<script type="text/javascript" src="'.find_in_path('_js/ui.core.js').'"></script>
<script type="text/javascript" src="'.find_in_path('_js/ui.datepicker.js').'"></script>
<script type="text/javascript" src="'.find_in_path('_js/ui.datepicker-'.$lang.'.js').'"></script>';
    }

    return $return;
}


// ajout
function balise_CIPARAM_URL_BASE_RELATIVE_dist($p) {
	$p->code = "ciparam_url_base_relative()";
	// $p->statut = 'html';
	return $p;
}

function ciparam_url_base_relative(){
    $return = '/';
    
    $path = parse_url($GLOBALS['meta']['adresse_site'], PHP_URL_PATH);
    if ($path){
        if (substr($path,-1)=='/'){
            $return = $path;
        } else {
            $return = $path.'/';
        }
    }
    
    return $return;
}


?>